backgroundColor property
The background color of the snackbar If null, will use type-specific default colors
Implementation
final Color? backgroundColor;
The background color of the snackbar If null, will use type-specific default colors
final Color? backgroundColor;