SnackbarXManager class

Singleton manager that ensures only one snackbar is visible at a time

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dismiss() → void
Dismisses the current snackbar if one is visible
init({GlobalKey<NavigatorState>? navigatorKey}) → void
Initializes the snackbar service
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show({required String message, required SnackbarType type, required SnackbarConfig config, BuildContext? context}) → void
Shows a snackbar with the given message and type
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance SnackbarXManager
Singleton instance
final